==> onefetch-2.12.0.tar.gz: onefetch-2.12.0/docs/README.fa.md <==
<div dir="rtl">

<h3 align="center"><img src="../assets/onefetch.svg" height="130px"></h3>

<h5 align="center">یک ابزار کامند لاینی برای نمایش دادن اطلاعات گیت نوشته شده با زبان برنامه‌نویسی راست</h5>

<p align="center">
	<a href="https://crates.io/crates/onefetch"><img src="https://img.shields.io/crates/v/onefetch.svg" alt="cargo"></a>
	<a href="https://github.com/o2sh/onefetch/actions"><img src="https://github.com/o2sh/onefetch/workflows/CI/badge.svg" alt="Build Status"></a>
  <a href="https://github.com/o2sh/onefetch/wiki/language-Support"><img src="../assets/language-badge.svg"></a>
	<a href="https://github.com/o2sh/onefetch/issues?q=is%3Aissue+is%3Aopen+label%3A%22help+wanted%22"><img src="https://img.shields.io/github/issues/o2sh/onefetch/help%20wanted?color=green" alt="help wanted"></a>
	<a href="./LICENSE.md"><img src="https://img.shields.io/badge/license-MIT-blue.svg"></a>
	<img src="../assets/msrv-badge.svg">
</p>

<img src="../assets/screenshot-1.png" align="left" height="240px">

Onefetch یک ابزار کامند لاینی نوشته شده با زبان راست است که اطلاعات پروژه و آمار کد را برای یک مخزن محلی گیت مستقیماً در ترمینال شما نمایش می دهد. این ابزار کاملا آفلاین است و به دسترسی اینترنت نیازی نیست.
  
به طور پیش‌فرض، اطلاعات ریپازیتوری در کنار لوگو زبان برنامه‌نویسی نمایش داده میشود.
  
شما میتوانید پیکربندی های بیشتری اعمال کنید تا بجای تصویر پیشفرض -در ترمینال های پشتیبانی شده- عکس یا متن دیکری نمایش داده شود.

این به طور خودکار مجوزهای منبع باز را از متن شناسایی می کند و اطلاعات ارزشمندی مانند توضیح ریپازیتوری ، تغییرات در حال انتظار ، تعداد وابستگی ها (توسط مدیر بسته) ، مشارکت کنندگان برتر (بر اساس تعداد کامیت ها) ، اندازه روی دیسک ، تاریخ ایجاد ریپازیتوری، LOC (تعداد خطوط کد) و غیره را در اختیار کاربر قرار می دهد.

<img src="../assets/screenshot-2.png" align="left" height="240px">

Onefetch را می توان از طریق پرچم های خط فرمان پیکربندی کرد تا دقیقاً همان چیزی را که می خواهید نمایش دهد ، همانطور که می خواهید: شما می توانید قالب‌بندی اَسکی/متن  را سفارش سازی کنید ، خطوط اطلاعات را غیرفعال کنید ، پرونده ها و دایرکتوری ها را نادیده بگیرید ، خروجی در چندین قالب (Json ، Yaml) قرار دهید  و کار های دیگر که این ابزار میتواند انجام دهد.

Onefetch  بیش از 50 زبان برنامه نویسی مختلف پشتیبانی می کند. اگر زبان انتخابی شما پشتیبانی نمی شود: [مسئله ای](https://github.com/o2sh/onefetch/issues/new/choose) را باز کنید و تا آن زبان به برنامه اضافه شود.

برای مشارکت بسیار خوش آمدید!  این  [فایل را](../CONTRIBUTING.md) برای اطلاعات بیشتر مطالعه کنید.

### سایر لینک ها: \[[ویکی](https://github.com/o2sh/onefetch/wiki)\] \[[نصب کردن](https://github.com/o2sh/onefetch/wiki/Installation)\] \[[شروع](https://github.com/o2sh/onefetch/wiki/getting-started)\]

</div>

==> onefetch-2.16.0.tar.gz: onefetch-2.16.0/docs/README.fa.md <==
<div dir="rtl">

<h3 align="center"><img src="../assets/onefetch.svg" height="130px"></h3>

<h5 align="center">یک ابزار کامند لاینی برای نمایش دادن اطلاعات گیت نوشته شده با زبان برنامه‌نویسی راست</h5>

<p align="center">
	<a href="https://crates.io/crates/onefetch"><img src="https://img.shields.io/crates/v/onefetch.svg" alt="cargo"></a>
	<a href="https://github.com/o2sh/onefetch/actions"><img src="https://github.com/o2sh/onefetch/workflows/CI/badge.svg" alt="Build Status"></a>
  <a href="https://onefetch.dev"><img src="../assets/language-badge.svg"></a>
	<a href="https://github.com/o2sh/onefetch/issues?q=is%3Aissue+is%3Aopen+label%3A%22help+wanted%22"><img src="https://img.shields.io/github/issues/o2sh/onefetch/help%20wanted?color=green" alt="help wanted"></a>
	<a href="./LICENSE.md"><img src="https://img.shields.io/badge/license-MIT-blue.svg"></a>
	<img src="../assets/msrv-badge.svg">
</p>

<img src="../assets/screenshot-1.png" align="left" height="240px">

Onefetch یک ابزار کامند لاینی نوشته شده با زبان راست است که اطلاعات پروژه و آمار کد را برای یک مخزن محلی گیت مستقیماً در ترمینال شما نمایش می دهد. این ابزار کاملا آفلاین است و به دسترسی اینترنت نیازی نیست.

به طور پیش‌فرض، اطلاعات ریپازیتوری در کنار لوگو زبان برنامه‌نویسی نمایش داده میشود.

شما میتوانید پیکربندی های بیشتری اعمال کنید تا بجای تصویر پیشفرض -در ترمینال های پشتیبانی شده- عکس یا متن دیکری نمایش داده شود.

این به طور خودکار مجوزهای منبع باز را از متن شناسایی می کند و اطلاعات ارزشمندی مانند توضیح ریپازیتوری ، تغییرات در حال انتظار ، تعداد وابستگی ها (توسط مدیر بسته) ، مشارکت کنندگان برتر (بر اساس تعداد کامیت ها) ، اندازه روی دیسک ، تاریخ ایجاد ریپازیتوری، LOC (تعداد خطوط کد) و غیره را در اختیار کاربر قرار می دهد.

<img src="../assets/screenshot-2.png" align="left" height="240px">

Onefetch را می توان از طریق پرچم های خط فرمان پیکربندی کرد تا دقیقاً همان چیزی را که می خواهید نمایش دهد ، همانطور که می خواهید: شما می توانید قالب‌بندی اَسکی/متن را سفارش سازی کنید ، خطوط اطلاعات را غیرفعال کنید ، پرونده ها و دایرکتوری ها را نادیده بگیرید ، خروجی در چندین قالب (Json ، Yaml) قرار دهید و کار های دیگر که این ابزار میتواند انجام دهد.

Onefetch بیش از 100 زبان برنامه نویسی مختلف پشتیبانی می کند. اگر زبان انتخابی شما پشتیبانی نمی شود: [مسئله ای](https://github.com/o2sh/onefetch/issues/new/choose) را باز کنید و تا آن زبان به برنامه اضافه شود.

برای مشارکت بسیار خوش آمدید! این [فایل را](../CONTRIBUTING.md) برای اطلاعات بیشتر مطالعه کنید.

### سایر لینک ها: \[[ویکی](https://github.com/o2sh/onefetch/wiki)\] \[[نصب کردن](https://github.com/o2sh/onefetch/wiki/Installation)\] \[[شروع](https://github.com/o2sh/onefetch/wiki/getting-started)\]

</div>
